you can run the various sample files to see the pipeline in action

validate folder:
share plugins across projects and overwrite settings

TODO:
share actions sample

TODO: expand interactive plugin adding in the UI